/*

  Author(s): Ilja V. Ryndin <support@rusbitech.ru>

  Start date: *

*/

#ifndef FLYFMCORE_H
#define FLYFMCORE_H

#include <QMap>
#include <QStringList>
#include <QVariant>

class QWidget;

namespace FlyFM
{

namespace Core
{

enum HaltReason { Exited = 0, Interrupted = 1, Segfaulted = 2 };

using ReleaseFuncType = void(*)();
using HaltHandlerFuncType = void(*)(HaltReason);

void moveForCenter(QWidget *);
void moveForPresentation(QWidget *);

QString md5HashForString(const QString &string);
QString dataSizeAsString(long long size); // Convert byte size to Kb, Mb, Gb
QString version();
QString versionedName();

void registerReleaseFunction(ReleaseFuncType);
void unregisterReleaseFunction(ReleaseFuncType);

void registerHaltHandlerFunction(HaltHandlerFuncType);
void unregisterHaltHandlerFunction(HaltHandlerFuncType);

int compareVariants(const QVariant &v1, const QVariant &v2);

bool startProcess(const QString &command);
bool startProcess(const QString &program, const QStringList &arguments, const QString &workingDirectory = QString());

}

}

#endif // FLYFMCORE_H
